15.134. cdist-type__sysctl(7) — cdist 4.10.4 documentation

# 15.134. cdist-type__sysctl(7)

## 15.134.1. NAME

cdist-type__sysctl - manage sysctl settings

## 15.134.2. DESCRIPTION

Manages permanent as well as runtime sysctl settings. Permament settings are set by managing entries in /etc/sysctl.conf. Runtime settings are set by directly calling the sysctl executable.

## 15.134.3. REQUIRED PARAMETERS

value
  The value to set for the given key (object_id)

## 15.134.4. EXAMPLES

    __sysctl net.ipv4.ip_forward --value 1

## 15.134.5. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 15.134.6. COPYING

Copyright (C) 2014 Steven Armstrong. Free use of this software is granted under the terms of the GNU General Public License version 3 or later (GPLv3+).